@@ -1,17 +1,15 @@
-=pod ############################################################################
-
-=head1 NAME
-
-Apache::Voodoo::Install - Base package for Apache::Voodoo::Install::* objects.
-
-=head1 SYNOPSIS
-
-This package provides some basic common methods needed by all the "real work"
-Apache::Voodoo::Install::* objects.
-
-=cut ###########################################################################
+############################################################################
+#
+# Apache::Voodoo::Install - Base package for Apache::Voodoo::Install::* objects.
+#
+# This package provides some basic common methods needed by all the "real work"
+# Apache::Voodoo::Install::* objects.
+#
+###########################################################################
 package Apache::Voodoo::Install;
 
+$VERSION = "3.0000";
+
 use strict;
 use warnings;
 
@@ -154,18 +152,13 @@ sub make_writeable_files {
 # sure which.
 
 1;
-=pod ################################################################################
 
-=head1 AUTHOR
-
-Maverick, /\/\averick@smurfbaneDOTorg
-
-=head1 COPYRIGHT
-
-Copyright (c) 2005 Steven Edwards.  All rights reserved.
-
-You may use and distribute Voodoo under the terms described in the LICENSE file include in
-this package or L<Apache::Voodoo::license>.  The summary is it's a legalese version of
-the Artistic License :)
-
-=cut ################################################################################
+################################################################################
+# Copyright (c) 2005-2010 Steven Edwards (maverick@smurfbane.org).  
+# All rights reserved.
+#
+# You may use and distribute Apache::Voodoo under the terms described in the 
+# LICENSE file include in this package. The summary is it's a legalese version
+# of the Artistic License :)
+#
+################################################################################
