@@ -1,21 +1,15 @@
-=pod ###########################################################################
-
-=head1 NAME
-
-Apache::Voodoo::Install::Updater
-
-=head1 VERSION
-
-$Id: Distribution.pm 6538 2008-02-04 19:11:38Z medwards $
-
-=head1 SYNOPSIS
-
-This package provides the methods that do pre/post/upgrade commands as specified
-by the various .xml files in an application.
-
-=cut ###########################################################################
+################################################################################
+#
+# Apache::Voodoo::Install::Updater
+#
+# This package provides the methods that do pre/post/upgrade commands as specified
+# by the various .xml files in an application.
+#
+################################################################################
 package Apache::Voodoo::Install::Distribution;
 
+$VERSION = "3.0000";
+
 use strict;
 use warnings;
 
@@ -234,18 +228,12 @@ sub install_files {
 
 1;
 
-=pod ################################################################################
-
-=head1 AUTHOR
-
-Maverick, /\/\averick@smurfbaneDOTorg
-
-=head1 COPYRIGHT
-
-Copyright (c) 2005 Steven Edwards.  All rights reserved.
-
-You may use and distribute Voodoo under the terms described in the LICENSE file include
-in this package or L<Apache::Voodoo::license>.  The summary is it's a legalese version
-of the Artistic License :)
-
-=cut ################################################################################
+################################################################################
+# Copyright (c) 2005-2010 Steven Edwards (maverick@smurfbane.org).  
+# All rights reserved.
+#
+# You may use and distribute Apache::Voodoo under the terms described in the 
+# LICENSE file include in this package. The summary is it's a legalese version
+# of the Artistic License :)
+#
+################################################################################
