@@ -1,20 +1,14 @@
-=pod ###########################################################################
-
-=head1 NAME
-
-Apache::Voodoo::Install::Pid - Pid file handler
-
-=head1 VERSION
-
-$Id: Pid.pm 6315 2007-11-16 18:52:40Z medwards $
-
-=head1 SYNOPSIS
-
-This object is used by Voodoo internally.
-
-=cut ###########################################################################
+###############################################################################
+#
+# Apache::Voodoo::Install::Pid - Pid file handler
+#
+# This object is used by Voodoo internally.
+#
+###############################################################################
 package Apache::Voodoo::Install::Pid;
 
+$VERSION = "3.0000";
+
 use base("Apache::Voodoo::Install");
 
 use strict;
@@ -68,18 +62,12 @@ sub DESTROY {
 
 1;
 
-=pod ###########################################################################
-
-=head1 AUTHOR
-
-Maverick, /\/\averick@smurfbaneDOTorg
-
-=head1 COPYRIGHT
-
-Copyright (c) 2005 Steven Edwards.  All rights reserved.
-
-You may use and distribute Voodoo under the terms described in the LICENSE 
-file include in this package or L<Apache::Voodoo::license>.  The summary is
-it's a legalese version of the Artistic License :)
-
-=cut ###########################################################################
+################################################################################
+# Copyright (c) 2005-2010 Steven Edwards (maverick@smurfbane.org).  
+# All rights reserved.
+#
+# You may use and distribute Apache::Voodoo under the terms described in the 
+# LICENSE file include in this package. The summary is it's a legalese version
+# of the Artistic License :)
+#
+################################################################################
